Geraldo Reports Engine
Description: Geraldo is a reports engine for Python or Django applications. It uses the power of ReportLab and PIL to generate reports with page header and footer, child bands, report begin and summary bands, agreggation and graphic elements, etc.
Keywords: Python, Django, reports, framework, open-source, engine

# Be welcome, this is Geraldo, a Python reports engine!

### Get Geraldo

You have four ways to get Geraldo.

#### Download the latest release

  Click here to get the latest release

#### Use easy_install

  easy_install geraldo

#### Subversion latest release repository

  svn co https://geraldo.svn.sourceforge.net/svnroot/geraldo/

#### GitHub trunk repository

  git clone git://github.com/marinho/geraldo.git

### Screenshots

Attention: The following screenshots are just generated by the test you can find in the source code package.

A simple report | Report with multiple-level groupping | Report with graphic images and shapes in landscape
Report with child bands in portrait | Report with charts generated by MatPlotLib | Report with charts generated by CairoPlot

### Code Snippets

Go to tag 'geraldo' on DjangoSnippets.org (you can also write yours own snippets, just use DjangoSnippets.org to write your snippets and tag them with "geraldo")

### Documentation

- Overview
- Installation
- Tutorial 1
- Basic
- Widgets
- Graphics
- Generators
- Backward Incompatible Changes
- Next steps

### Issues

If you have bug, suggestion, improvement or a patch to send, please open an issue. If you want to help us to improve Geraldo, you can also browse the existing issues and send your thoughts or patches.

- Open a New Issue
- Browse existing ones

*New! Keep updated about Geraldo, following @geraldoreports on Twitter

Geraldo is a reports engine for Python or Django applications. It uses the power of ReportLab and PIL to generate reports with page header and footer, child bands, report begin and summary bands, agreggation and graphic elements, etc.

Geraldo is not dependent of anyone specific Python framework. You can use it in standalone desktop applications and web applications. It is platform independent and will work well in Linux, Mac or Windows in the most of available versions and editions.

Geraldo is under LGPL 3.0 (Lesser Gnu Public License) and you are free do download, copy, distribute and modify with no needs to pay nothing to nobody, since you respect the license terms.

If you are looking for example codes on using Geraldo Reports, you can look in the package the directory 'test' and you will find dozens of them.

Click here to contact us.

## How to contribute

There are many ways you can contribute with the project.

- Reporting bugs and suggestions - if you have an idea or bug to report, please open a ticket and leave there your toughts.
- Writing a post or tutorial on your blog - you can use your blog or website to write about and help people to know and how to use Geraldo.
- Writing documentation - our documentation must be improved (specially the english gramatic).
- Writing third-part tools - there are some utilities you can create to use together Geraldo with no necessarily change the core code.
- Going ahead into the code - you can go to our tickets page and write patches for existing tickets. You can also read our next goals and contribute writing them.
- Using your feeling - use your imagination and you can find other ways to help Geraldo Reports to be better. Be welcome!

If you want to participate on Geraldo development, be welcome and join our discussion group, on http://groups.google.com.br/group/geraldo-developers

This site is still under construction, please keep coming back to see updates.